pub struct MarketOrder {
pub protection_price: Option<Price>,
/* private fields */
}Fields
protection_price: Option<Price>Implementations
Sourceimpl MarketOrder
impl MarketOrder
Sourcepub fn new_checked(
trader_id: TraderId,
strategy_id: StrategyId,
instrument_id: InstrumentId,
client_order_id: ClientOrderId,
order_side: OrderSide,
quantity: Quantity,
time_in_force: TimeInForce,
init_id: UUID4,
ts_init: UnixNanos,
reduce_only: bool,
quote_quantity: bool,
contingency_type: Option<ContingencyType>,
order_list_id: Option<OrderListId>,
linked_order_ids: Option<Vec<ClientOrderId>>,
parent_order_id: Option<ClientOrderId>,
exec_algorithm_id: Option<ExecAlgorithmId>,
exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>,
exec_spawn_id: Option<ClientOrderId>,
tags: Option<Vec<Ustr>>,
) -> Result<Self, OrderError>
pub fn new_checked( trader_id: TraderId, strategy_id: StrategyId, instrument_id: InstrumentId, client_order_id: ClientOrderId, order_side: OrderSide, quantity: Quantity, time_in_force: TimeInForce, init_id: UUID4, ts_init: UnixNanos, reduce_only: bool, quote_quantity: bool, contingency_type: Option<ContingencyType>, order_list_id: Option<OrderListId>, linked_order_ids: Option<Vec<ClientOrderId>>, parent_order_id: Option<ClientOrderId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, exec_spawn_id: Option<ClientOrderId>, tags: Option<Vec<Ustr>>, ) -> Result<Self, OrderError>
Creates a new MarketOrder instance.
Errors
Returns an error if:
- The
quantityis not positive. - The
time_in_forceis GTD (invalid for market orders). - The order metadata violates an
OrderInitialized::new_checkedinvariant.
Sourcepub fn new(
trader_id: TraderId,
strategy_id: StrategyId,
instrument_id: InstrumentId,
client_order_id: ClientOrderId,
order_side: OrderSide,
quantity: Quantity,
time_in_force: TimeInForce,
init_id: UUID4,
ts_init: UnixNanos,
reduce_only: bool,
quote_quantity: bool,
contingency_type: Option<ContingencyType>,
order_list_id: Option<OrderListId>,
linked_order_ids: Option<Vec<ClientOrderId>>,
parent_order_id: Option<ClientOrderId>,
exec_algorithm_id: Option<ExecAlgorithmId>,
exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>,
exec_spawn_id: Option<ClientOrderId>,
tags: Option<Vec<Ustr>>,
) -> Self
pub fn new( trader_id: TraderId, strategy_id: StrategyId, instrument_id: InstrumentId, client_order_id: ClientOrderId, order_side: OrderSide, quantity: Quantity, time_in_force: TimeInForce, init_id: UUID4, ts_init: UnixNanos, reduce_only: bool, quote_quantity: bool, contingency_type: Option<ContingencyType>, order_list_id: Option<OrderListId>, linked_order_ids: Option<Vec<ClientOrderId>>, parent_order_id: Option<ClientOrderId>, exec_algorithm_id: Option<ExecAlgorithmId>, exec_algorithm_params: Option<IndexMap<Ustr, Ustr>>, exec_spawn_id: Option<ClientOrderId>, tags: Option<Vec<Ustr>>, ) -> Self
Creates a new MarketOrder instance.
Panics
Panics if any order validation fails (see MarketOrder::new_checked).
Methods from Deref<Target = OrderCore>
Sourcepub fn apply(&mut self, event: OrderEventAny) -> Result<(), OrderError>
pub fn apply(&mut self, event: OrderEventAny) -> Result<(), OrderError>
Applies the event to the order.
Errors
Returns an error if the event is invalid for the current order status, or if
event.client_order_id() or event.strategy_id() does not match the order.
pub fn set_slippage(&mut self, price: Price)
pub fn signed_decimal_qty(&self) -> Decimal
pub fn would_reduce_only( &self, side: PositionSide, position_qty: Quantity, ) -> bool
pub fn commission(&self, currency: &Currency) -> Option<Money>
pub fn commissions(&self) -> IndexMap<Currency, Money>
pub fn commissions_vec(&self) -> Vec<Money>
Sourcepub fn events(&self) -> &[OrderEventAny]
pub fn events(&self) -> &[OrderEventAny]
Returns the order events in application order.
Sourcepub fn prepend_events(
&mut self,
events: impl IntoIterator<Item = OrderEventAny>,
)
pub fn prepend_events( &mut self, events: impl IntoIterator<Item = OrderEventAny>, )
Prepends historical events in iterator order without applying their state transitions.
Used when transforming an order into another type. The next fill rebuilds the average-price fold from the combined history; other derived state is unchanged.
pub fn init_event(&self) -> Option<OrderEventAny>